@@ -430,7 +430,7 @@ def _mixup_labels(shape, label1, label2, n_classes, a):
     return (1 - a) * lab1 + a * lab2
 
 
-def cutmix(batch, label, prob=1.0, dimension=256, n_classes=1):
+def cutmix(batch, label, prob=1.0, dimension=256, n_classes=1, n_labels=None):
     """
     Cutmix randomly remove squares from training images
 
@@ -456,9 +456,9 @@ def cutmix(batch, label, prob=1.0, dimension=256, n_classes=1):
     tf.Tensor
         A batch of images with Cutmix applied
     """
-    P = tf.cast(tf.random.uniform([], 0, 1) < prob, tf.int32)
-    if (P == 0):
-        return batch  # no action
+    #P = tf.cast(tf.random.uniform([], 0, 1) < prob, tf.int32)
+    #if (P == 0):
+    #    return batch, label  # no action
 
     DIM = dimension
     rank = len(batch.shape) - 2
@@ -506,7 +506,10 @@ def cutmix(batch, label, prob=1.0, dimension=256, n_classes=1):
     else:
         image2 = tf.reshape(tf.stack(imgs), (batch_size, DIM, DIM, DIM, 3))
 
-    label2 = tf.reshape(tf.stack(labs), (batch_size, n_classes))
+    if n_labels:
+        label2 = tf.reshape(tf.stack(labs), (batch_size, n_labels))
+    else:
+        label2 = tf.reshape(tf.stack(labs), (batch_size, n_classes))
     return image2, label2
 
 
@@ -536,9 +539,9 @@ def mixup(batch, label, prob=1.0, dimension=256, n_classes=1):
     tf.Tensor
         A batch of images with Mixup applied
     """
-    P = tf.cast(tf.random.uniform([], 0, 1) < prob, tf.int32)
-    if (P == 0):
-        return batch  # no action
+    #P = tf.cast(tf.random.uniform([], 0, 1) < prob, tf.int32)
+    #if (P == 0):
+        #return batch, label  # no action
 
     DIM = dimension
     CLASSES = n_classes
